/* --------------------------------------------------------------------------------------------
 * Copyright (c) 2024 TypeFox GmbH (http://www.typefox.io). All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
import getEditorServiceOverride from '@codingame/monaco-vscode-editor-service-override';
import getKeybindingsServiceOverride from '@codingame/monaco-vscode-keybindings-service-override';
import { useOpenEditorStub } from 'monaco-editor-wrapper/vscode/services';
import { getTextContent } from '../../../common/example-apps-common.js';
export const createLangiumGlobalConfig = async (worker, messagePort) => {
    const code = await getTextContent(new URL('./src/langium/statemachine/content/example.statemachine', window.location.href));
    const extensionFilesOrContents = new Map();
    const statemachineLanguageConfig = new URL('./src/langium/statemachine/config/language-configuration.json', window.location.href);
    const responseStatemachineTm = new URL('./src/langium/statemachine/syntaxes/statemachine.tmLanguage.json', window.location.href);
    extensionFilesOrContents.set('/statemachine-configuration.json', statemachineLanguageConfig);
    extensionFilesOrContents.set('/statemachine-grammar.json', responseStatemachineTm);
    return {
        wrapperConfig: {
            serviceConfig: {
                userServices: {
                    ...getEditorServiceOverride(useOpenEditorStub),
                    ...getKeybindingsServiceOverride()
                },
                debugLogging: true
            },
            editorAppConfig: {
                $type: 'extended',
                languageId: 'statemachine',
                code: code,
                useDiffEditor: false,
                extensions: [{
                        config: {
                            name: 'statemachine-example',
                            publisher: 'monaco-editor-wrapper-examples',
                            version: '1.0.0',
                            engines: {
                                vscode: '*'
                            },
                            contributes: {
                                languages: [{
                                        id: 'statemachine',
                                        extensions: ['.statemachine'],
                                        aliases: ['statemachine', 'Statemachine'],
                                        configuration: './statemachine-configuration.json'
                                    }],
                                grammars: [{
                                        language: 'statemachine',
                                        scopeName: 'source.statemachine',
                                        path: './statemachine-grammar.json'
                                    }]
                            }
                        },
                        filesOrContents: extensionFilesOrContents
                    }],
                userConfiguration: {
                    json: JSON.stringify({
                        'workbench.colorTheme': 'Default Dark Modern',
                        'editor.guides.bracketPairsHorizontal': 'active',
                        'editor.wordBasedSuggestions': 'off'
                    })
                }
            }
        },
        languageClientConfig: {
            options: {
                $type: 'WorkerDirect',
                worker,
                messagePort
            }
        }
    };
};
//# sourceMappingURL=wrapperStatemachineConfig.js.map